#!/bin/bash

source $(dirname $0)/utils.sh

# Check mysql installed.
check_program mysql
